@@ -1,5 +1,5 @@
 package AI::NaiveBayes;
-$AI::NaiveBayes::VERSION = '0.02';
+$AI::NaiveBayes::VERSION = '0.03';
 use strict;
 use warnings;
 use 5.010;
@@ -79,7 +79,7 @@ AI::NaiveBayes - A Bayesian classifier
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -89,11 +89,16 @@ version 0.02
 
     my $classifier = AI::NaiveBayes->train( 
         {
-            attributes => _hash(qw(sheep very valuable farming)),
+            attributes => {
+                sheep => 1, very => 1,  valuable => 1, farming => 1
+            },
             labels => ['farming']
         },
         {
-            attributes => _hash(qw(vampires cannot see their images mirrors)),
+            attributes => {
+                vampires => 1, cannot => 1, see => 1, their => 1,
+                images => 1, mirrors => 1
+            },
             labels => ['vampire']
         },
     );
